reporust_rebootcancel

156,845 Commits over 4,566 Days - 1.43cph!

Today
Fix SelectedBlueprint.CanCraft running every frame while the crafting menu is closed, small but unnecessary
Today
scrap king building skin steam item setup
Today
Add support for major/minor revision bumping. Update all gamepad configs with this data. Update validation to always check/catch chamges.
Today
Fix all skinned items allocating on every inventory update when getting their icon sprite
Today
Attack/AttackAlt are now Button actions on the triggers' soft pull so players can rebind fire/aim to any button (per Valve guidance). Update all action sets/configs to match,
Today
merge from main
Today
Stop any rumble in Deactivate
▆ ▋ ▆█▍▄▋ ▇▋▅▆ ▌▋▇▍▇ ▊▅▅ █▍▅▌ ▇▍▄▌▄▋▌ ▅▊▆▉▇▇█ ▇▌▉▅▋ ▊█▇▆▆▆ ▇▄▊▍▉▍▄ ▅▍▌ █▌▆▊▊▍▄▊▊ ▅▍▊▍▇▇ ▉▇ ▆▉█ ▄▋▌▊ ▊▋▅▆▅▆▉▆█ ▉▍▍▇█ ▄▊▇▊▉ ▄▆▊▄ ▇▉▍▊▋▊█▌▊▄▊▄▍▋▋██ ▉▋▆▇
▆ ▉█▉▅▉ ▍▇▆▊ ▇▋▍▆ ▅▌▍▊▄▍█ ▅ ▅▍▊██▉▊▉ ▊▊▊█ ▍▅▄▊ ▅▇▄ ▉▇▍▅ ▊ ▌▅▍█ ▅▅ ▉▅▆▄██▍▊ ▅▇▋▊▄
Today
merge from render_pipeline_testing
Today
remove the Rust Render Pipeline text when RRP is enabled, instead show Built-In Render Pipeline when RRP is disabled
Today
Try/catch the gamepad update loop, disable on any error errors.
Today
Fixed quick craft spending ~1.6ms rebuilding after almost every shot (inventory update) Only rebuilds when the inventory is open now
Today
fix stale frame on subsystems without fade in, fix flare not having a predict release event, remove fade in on flare subsystem to fix weird flipping artifact on flare
Today
merge from cache_entity_links -> main
Today
Update comment
Today
merge from automated_testing
Today
Get rid of some debug logs spamming related to halloween dungeon spawning
Today
Re-add the "Restoring X/100,000 links" for cases where the cache links aren't used
Today
merge from render_pipeline_testing
Today
fix RRP drawing ocean after water bodies
Today
Halloween stringlights Improve deployment, stop clipping, fix groundwatch, reduce network range, remove snapping All tests pass
Today
Pool 3 copies of thrown melee weapon and tool projectiles instead of 100. No point in filling our pool with 3900 copies you'll rarely see more than 3 of at the same time Saves around 50MB of memory and gives me some leeway to eat that with gun effects next
Today
▍ ▌▇▉▆▋ ▅▌▅▉▄▍▆ ▅▄▆▅▆ ▅▅▄▄ ▉█ ▇▆▄▄█ ▄█▍▇▊█▋ ▋▅ █▉▋██▆▋▊▊ ▊▋▅▇▆▊█▊▍▇▍ ▅▍▊▄ ▇▅▄ ▅▊▊▊ ▇█▍ ▋▊ █▊▊▇▊▋ ▊▇▇▇▊▆▆ ▌▄▉█▌ ▍▉▌ ▊▅▇▅▊▍▄▄▇▊▇█ ▄▄▍ ▆▍▇█▇ ▇▊▍ █▋▌▋ ▊▅▍▊ ▄▆▋▋█ ▇▅▍▋▊▇▍▋▇▋▆
Today
Pass `serverStartup` parameter into RestoringLoadedEntityLinks() so we don't call RCON.Update() when pasting with copypaste - probably harmless but it bugged me
Today
Increase stick move distance required to activate gamepad
Today
merge from cache_ocean_path -> main
Codegen
Today
Optimize server startup time by caching the ocean patrol path on disk (158s -> 138s) - same idea as server occlusion grid being saved - can increase version number to regenerate next restart - convar `regenerate_ocean_path` will cause it to regenerate it next startup too
Today
Codegen
Remove three unused floats (skincol, skintex, skinmesh) from all player net messages that havent been used since 2016 Defaults were set to -1 so included in the proto Saves 17 bytes per player
Today
merge from main
Today
Prewarm 5 copies of each ricochet effect instead of 1, first magazine dumped after connecting created up to 2 more per prefab at ~0.5ms each
Stop networking IO wire origin data and duplicate slack levels to clients Saves ~34 B per wired slot + ~5 B per wire point on network load
Fix flame turret sending two updates per trigger change instead of one Saves 60 B~ per nearby player each time the turret turns on or off
Today
Update test list
Stop water purifier sending two unchanged network updates per boil tick 30 B/s~ per nearby player
Dont send environment rainGraceStartTicks (only used on the server) Sends every 5 seconds. 54 → 44 B per update, so saves 10 B~ every per player every 5s
Door.SetOpen no longer sends a full network update when the door is already in the requested state (door closers re-close shut doors 3 s after every open/close cycle) Saves ~76 B per nearby player per call
Today
merge from main -> cache_entity_links
Only send search light network updates when aim/flags change rather than per tick when mounted
▄ ▉▄▉▆▄ ▇▋▍▄ ▄▅▇▆▊▍█▅▄▌█▋█▋▆▆▍▄▌▅▍▌█▉▋▌▍▉
█▆▇▇▌▅ ▌▆▌▊ ▇█▋▋▍▇▄▉▄█▇▉▇█▅▉▄█▊▇▊▉▄▉█▌▅▌
Today
merge from optimize_duplicate_player_check -> main
▍ ▇▆▋ █ ▉▉▋█▉▅ ▄▊▅▌█ ▋▋▍▇▍▋▌▇▌ ▊█▉▋ ▍▉▋▌█▇▋▊▋▊█ ▇▊ ▅▄▉▅▍▍▆▄▄▉ ▅▄▇▅▉▌▌▋▄ ▍▍ █▄▇ ▆▅▋▅▌▄▅█▍▆ ▊▌▌▋▊▉▇▋▍▍▊ ▋▄▆▅ ▋▍ ▌██ ▋▊▍▅▍▌▅▄▅▄█▋▅▅▉▋▄▅▅ █▉ ▅▉▄▋█▄▉ ▄▄▄ ▆▄█▉▄▌ ▊▌▌ ▇▆▉▍▉▍ ▊▍▋▇▋▌
Dont send travelling vendor map marker updates 20 frames a second Saves 160 bytes per network tick when the vendor is out
Today
merge from optimize_enforce_limits -> main
Today
Create the pools LaunchProjectileClientside uses at bootstrap instead of on the first shot, avoids a ~365KB alloc when the first projectile of the session is fired
Remove old mortar prototype code Means we can remove an mortarCooldown float with every BasePlayer update Saves 6 bytes per player update
Today
merge from fix_steam_setkey_crash -> main